summaryrefslogtreecommitdiff
path: root/libopie/pim/opimaccessbackend.h
Side-by-side diff
Diffstat (limited to 'libopie/pim/opimaccessbackend.h') (more/less context) (show whitespace changes)
-rw-r--r--libopie/pim/opimaccessbackend.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/libopie/pim/opimaccessbackend.h b/libopie/pim/opimaccessbackend.h
index e268f4f..01a0c86 100644
--- a/libopie/pim/opimaccessbackend.h
+++ b/libopie/pim/opimaccessbackend.h
@@ -44,16 +44,16 @@ public:
* return an array of
* all available uids
*/
virtual QArray<int> allRecords()const = 0;
/**
* queryByExample for T with the SortOrder
* sort
*/
- virtual QArray<int> queryByExample( const T& t, int sort ) = 0;
+ virtual QArray<int> queryByExample( const T& t, int settings, const QDateTime& d = QDateTime() ) = 0;
/**
* find the OPimRecord with uid @param uid
* returns T and T.isEmpty() if nothing was found
@@ -44,16 +44,16 @@ public:
virtual QArray<int> allRecords()const = 0;
/**
- * queryByExample for T with the SortOrder
- * sort
+ * queryByExample for T with the given Settings
+ *
*/
*/
virtual T find(int uid )const = 0;